#!/usr/bin/env python

import os

import sys



def main():

    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'drive.settings')

    try:

        from django.core.management import execute_from_command_line

    except ImportError as exc:

        raise ImportError(

            "Couldn't import Libraries. Are you sure they are installed and "

            "available on your PYTHONPATH environment variable? Did you "

            "forget to activate a virtual environment?"

        ) from exc

    execute_from_command_line(["manage.py", "runserver", "0.0.0.0:8000"])





if __name__ == '__main__':

    main()


from django.contrib.gis.db import models
from django.contrib.auth.models import User
# Create your models here.




class Vehicle(models.Model):
    user = models.ForeignKey(User,on_delete = models.CASCADE)
    make = models.CharField(max_length=50)
    model = models.CharField(max_length=50)
    plateNum = models.CharField(max_length=6, default=' ')

    def __str__(self):
        return self.make + " " + self.model

class ParkingSpot(models.Model):
    owner = models.ForeignKey(User, on_delete=models.CASCADE)
    location = models.PointField()
    address = models.CharField(max_length=100)
    city = models.CharField(max_length=50)
    upload_image = models.ImageField(upload_to='userface/media/parkingspot_uploads/', default='userface/media/parkingspot_uploads/default_image.jpg')
    available = models.BooleanField(default=True)
    pending = models.BooleanField(default=False)
    def __str__(self):
        return self.address


class Destination(models.Model):
    user = models.ForeignKey(User, on_delete=models.CASCADE)
    address = models.CharField(max_length=100)
    location = models.PointField()
    city = models.CharField(max_length=50)


class UserLocation(models.Model):
    owner = models.ForeignKey(User, on_delete=models.CASCADE)
    location = models.PointField()

class UserDetails(models.Model):
    owner = models.ForeignKey(User, on_delete=models.CASCADE)
    number = models.CharField(max_length = 20)




from django.contrib.gis import admin
from django.contrib.gis.admin import OSMGeoAdmin
# Register your models here.
from .models import User, Vehicle, ParkingSpot, Destination


#admin.site.register(User)
admin.site.register(Vehicle)

@admin.register(ParkingSpot)
class ParkingSpotAdmin(OSMGeoAdmin):
    list_display = ('owner', 'location')

@admin.register(Destination)
class ParkingSpotAdmin(OSMGeoAdmin):
    list_display = ('user', 'location')
# class ChoiceInline(admin.TabularInline):
#     model = Vehicle
#     extra = 1
#
#
# class UserAdmin(admin.ModelAdmin):
#     fieldsets = [(None, {'fields': ["first_name", "last_name"]}),
#                  ('Date Information', {'fields': ['date_joined'], 'classes': ['collapse']}), ]
#     inlines = [ChoiceInline]
#
#
# admin.site.register(User,UserAdmin)


from django import forms
from django.contrib.auth.forms import UserCreationForm
from django.contrib.auth.models import User
from userface.models import Vehicle
from userface.models import ParkingSpot
from crispy_forms.helper import FormHelper
from crispy_forms.layout import Submit


class RegisterForm(UserCreationForm):
    email = forms.EmailField()
    first_name = forms.CharField
    last_name = forms.CharField

    class Meta:
        model = User
        fields = ["username", "email", "first_name", "last_name", "password1", "password2"]


class VehicleForm(forms.ModelForm):
    make = forms.CharField(label="Make", required=True)
    model = forms.CharField(label="Model", required=True)
    plateNum = forms.CharField(label="License Plate", required=True)
    #color = forms.CharField(label="Color", required=True)

    helper = FormHelper()
    helper.form_method = 'POST'

    helper.add_input(Submit('Save', 'Save', css_class='btn-primary'))

    class Meta:
        model = Vehicle
        fields = ["make", "model", "plateNum"]

class ParkingSpaceForm(forms.ModelForm):
    address = forms.CharField(label="Address", required=True)
    city = forms.CharField(label="City", required=True)
    helper = FormHelper()
    helper.form_method = 'POST'
    helper.add_input(Submit('List', 'List', css_class='btn-primary'))
    #helper.form_tag = False
    #helper.form_id = 'addspot'

    class Meta:
        model = ParkingSpot
        fields = ["address", "city", "upload_image"]




from django.urls import path
import re
from . import views
from django.conf.urls import url

app_name = 'userface'
urlpatterns = [
    path('', views.index, name='index'),
]

urlpatterns += [
    path('myvehicles/', views.VehicleListView.as_view(), name='my-vehicles'),
    path('myparking/', views.ParkingSpotListView.as_view(), name='myparking'),
    path('register/', views.register, name='register'),
    path('search/', views.search, name='search'),
    path('registervehicle/',views.registervehicle, name = 'registervehicle'),
    path('addspot/',views.addspot, name = 'addspot'),
    path('portal',views.portal, name = 'portal'),
    path('book/<int:parkingspot_id>/',views.book, name = 'book'),
    path('book/confirm/<int:parkingspot_id>/',views.confirm, name = 'confirm')
    #url(r'^mapview/(?P<pk>[0-9]+)$', views.DestinationDetailView.as_view(), name='search_results')
]



from django.shortcuts import render, redirect
from django.views import generic
from .models import User, Vehicle, ParkingSpot, Destination, UserDetails
from django.contrib.auth.mixins import LoginRequiredMixin
from django.contrib.gis.geos import Point
from django.contrib.gis.geos import fromstr
from django.contrib.gis.measure import Distance, D
from geopy.distance import distance
from django.contrib.auth.decorators import login_required
# Create your views here.
from .forms import RegisterForm, VehicleForm, ParkingSpaceForm
#from django.contrib.gis.geoip2 import GeoIP2
from django.contrib.gis.geos import fromstr
from geopy.geocoders import Nominatim
from geopy.exc import GeocoderTimedOut
from django.views.generic import DetailView


def words_to_point(q):
    geolocator = Nominatim(user_agent="driveways")
    location = geolocator.geocode(q)
    point = Point(location.latitude, location.longitude)
    return point



def index(request):

    return render(request, 'userface/index.html')


def portal(request):

    return render(request, 'userface/adminportal.html')

def search(request):

    if request.method == "GET":
        resultss = request.GET.get('results', False)
        if not resultss:
            resultss = ""

        try:

            destination = words_to_point(resultss)

        except (GeocoderTimedOut, AttributeError) as e:
            request.session['spot'] = []
            return render(request, 'userface/search.html', {'resultss': resultss})

        spot_distance = request.GET.get('distance', False )
        try:
            val = int(spot_distance)
        except ValueError:
            print("That's not an int!")
            spot_distance = 3
        request.session['spot'] = "unknown"
        if request.user.is_authenticated:
            c_user = request.user
            dest = c_user.destination_set.create(
                address=resultss, location=destination)
            dest.save()
            request.session['spot'] = []
            near_spots = ParkingSpot.objects.filter(
                location__distance_lt=(destination, Distance(km=spot_distance)))
            for spot in near_spots:
                if len(spot.address) > 0:
                    try :

                        details = UserDetails.objects.get(owner = spot.owner)
                        number = details.number

                    except UserDetails.DoesNotExist:
                        number = ""

                    request.session['spot'].append(
                        {"address": spot.address,
                         "owner": spot.owner.first_name + " " + spot.owner.last_name,
                         "image_path": spot.upload_image.url,
                         "lon": spot.location.y,
                         "lat": spot.location.x,
                         "number": number,
                         "available": spot.available,
                         "id": spot.id})
    return render(request, 'userface/search.html', {'resultss': resultss, 'dest': dest})


def register(response):
    if response.method == "POST":
        form = RegisterForm(response.POST)
        if form.is_valid():
            form.save()

        return redirect("/userface")
    else:
        form = RegisterForm()

    return render(response, "registration/register.html", {"form": form})


class VehicleListView(LoginRequiredMixin, generic.ListView):
    model = Vehicle
    #context_object_name = 'vehicles'
    template_name = 'userface/user_vehicle_list.html'

    def get_queryset(self):
        return Vehicle.objects.filter(user=self.request.user)[:5]

class ParkingSpotListView(LoginRequiredMixin, generic.ListView):
    model = ParkingSpot
    #context_object_name = 'vehicles'
    template_name = 'userface/parking_spot_list.html'

    def get_queryset(self):
        return ParkingSpot.objects.filter(owner=self.request.user)[:]

def registervehicle(request):
    if request.method == 'POST':
        form = VehicleForm(request.POST)
        if form.is_valid():
            vehicle = form.save(commit=False)
            vehicle.make = form.cleaned_data.get('make')
            vehicle.model = form.cleaned_data.get('model')
            vehicle.plateNum = form.cleaned_data.get('plateNum')
            vehicle.user = request.user
            vehicle.save()
        return redirect("/userface/myvehicles")
    else:
        form = VehicleForm()

    return render(request, "userface/register_vehicle.html", {"form": form})


def addspot(request):
    if request.method == 'POST':
        form = ParkingSpaceForm(request.POST)
        if form.is_valid():
            parkingspot = form.save(commit=False)
            parkingspot.address = form.cleaned_data.get('address')
            parkingspot.city = form.cleaned_data.get('city')
            fullAddress = form.cleaned_data.get(
                'address') + " " + form.cleaned_data.get('city')
            parkingspot.location = words_to_point(fullAddress)
            parkingspot.owner = request.user
            parkingspot.save()
        return redirect("/userface/myparking")
    else:
        form = ParkingSpaceForm()

    return render(request, "userface/addspot.html", {"form": form})


def book(request, parkingspot_id):
    try:
        spot = ParkingSpot.objects.get(pk = parkingspot_id)
    except ParkingSpot.DoesNotExist:
        raise  Http404("Spot does not exist.")
    return render(request, 'userface/book.html', {'spot': spot})

def confirm(request, parkingspot_id):
    try:
        spot = ParkingSpot.objects.get(pk = parkingspot_id)
        spot.available = False
        spot.save()
    except ParkingSpot.DoesNotExist:
        raise  Http404("Error")
    return render(request, 'userface/confirm.html', {'spot': spot})



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="driveway",  # Replace with your own username
    version="0.1.4",
    author="Andres Canas, Henry Parker, Dylan Fay, Zack Saadioui",
    description="Driveways Package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/henryparker/drivewaynew",
    packages=['drive', 'userface', 'sample_app', ],
    py_modules=["manage"],
    include_package_data=True,
    install_requires=['asgiref', 'astroid', 'certifi', 'Django', 'django-crispy-forms', 'django-leaflet',
                      'geographiclib', 'geopy', 'idna', 'psycopg2-binary', 'pytz', 'requests>=2.24.0', 'six',
                      'sqlparse', 'toml', 'urllib3', 'wrapt', 'Pillow', 'geoip2'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',

    entry_points=

    {'console_scripts':

        [

            'runmyserver = sample_app.run:main',

        ]

    },
)




#!/usr/bin/env python

import os

import sys




def main():

    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'drive.settings')

    try:

        from django.core.management import execute_from_command_line

    except ImportError as exc:

        raise ImportError("Couldn't import Django.") from exc



if __name__ == '__main__':

    main()